@@ -29,7 +29,7 @@ from logilab.common import attrdict
 from yams import BASE_TYPES
 
 from cubicweb.predicates import is_instance
-from cubicweb.view import EntityAdapter
+from cubicweb_web.view import EntityAdapter
 
 from ..xsd import XSDM_MAPPING, JUMP_ELEMENTS
 from ..xsd2yams import SKIP_ATTRS
@@ -60,8 +60,8 @@ def substitute_xml_prefix(prefix_name, namespaces):
 
 
 def content_types(content_type):
-    """Return an ordered tuple of content types from pyxst `textual_content_type` that may be None, a
-    set or a string value.
+    """Return an ordered tuple of content types from pyxst `textual_content_type` that may be None,
+    a set or a string value.
     """
     if content_type:
         if isinstance(content_type, set):
