@@ -23,8 +23,8 @@ from logilab.common.decorators import monkeypatch
 
 from cubicweb import tags, _
 from cubicweb.predicates import is_instance, match_form_params, specified_etype_implements
-from cubicweb.view import EntityView
-from cubicweb.web.views import autoform, baseviews, tabs, uicfg
+from cubicweb_web.view import EntityView
+from cubicweb_web.views import autoform, baseviews, tabs, uicfg
 
 from cubicweb_compound import views as compound
 from cubicweb_relationwidget import views as rwdg
@@ -88,8 +88,8 @@ def is_archive_unit_ref(cls, req, rset=None, entity=None, **kwargs):
 
 @objectify_predicate
 def is_simple_keyword(cls, req, rset=None, entity=None, **kwargs):
-    """Return 1 if a keyword_type value is specified in kwargs or in form parameters, and its value is
-    'simple_keyword', or if given entity is not linked to a keyword reference.
+    """Return 1 if a keyword_type value is specified in kwargs or in form parameters, and its value
+    is 'simple_keyword', or if given entity is not linked to a keyword reference.
     """
     try:
         # first check for unit_type specified in form params
@@ -176,8 +176,8 @@ pvs.tag_subject_of(
 
 
 class SkipIBreadCrumbsAdapter(compound.IContainedBreadcrumbsAdapter):
-    """IBreadCrumbsAdapter for entities which should not appears in breadcrumb, we want to go back to
-    the parent
+    """IBreadCrumbsAdapter for entities which should not appears in breadcrumb, we want to go back
+    to the parent
     """
     __select__ = is_instance('SEDAAltArchiveUnitArchiveUnitRefId',
                              CONTENT_ETYPE)
