@@ -19,8 +19,8 @@ from logilab.common.registry import objectify_predicate
 
 from cubicweb import view, _
 from cubicweb.predicates import is_instance, one_line_rset
-from cubicweb.web import httpcache, action
-from cubicweb.web.views import idownloadable
+from cubicweb_web import httpcache, action
+from cubicweb_web.views import idownloadable
 
 
 @objectify_predicate
