@@ -16,7 +16,7 @@
 """Search facets for cubicweb-seda."""
 
 from cubicweb.predicates import is_instance
-from cubicweb.web.facet import AttributeFacet
+from cubicweb_web.facet import AttributeFacet
 
 
 class SimplifiedProfileFacet(AttributeFacet):
