@@ -17,7 +17,7 @@
 
 from cubicweb.predicates import (is_instance, multi_lines_rset,
                                  has_related_entities, relation_possible)
-from cubicweb.web.views import basecomponents, baseviews, ibreadcrumbs, urlrewrite
+from cubicweb_web.views import basecomponents, baseviews, ibreadcrumbs, urlrewrite
 
 
 class SEDAReqRewriter(urlrewrite.SimpleReqRewriter):
