@@ -22,7 +22,7 @@ from six import text_type
 from six.moves import zip
 
 from cubicweb.devtools.testlib import CubicWebTC
-from cubicweb.web import INTERNAL_FIELD_VALUE
+from cubicweb_web import INTERNAL_FIELD_VALUE
 
 from cubicweb_seda.xsd2yams import RULE_TYPES
 from cubicweb_seda.views import archiveunit, clone, export, mgmt_rules
@@ -159,7 +159,7 @@ class RelationWidgetTC(CubicWebTC):
 
 class HelperFunctionsTC(CubicWebTC):
     def test_rtags_from_xsd_element(self):
-        from cubicweb.web.views.uicfg import reledit_ctrl
+        from cubicweb_web.views.uicfg import reledit_ctrl
         from cubicweb_seda.views import rtags_from_xsd_element
 
         rsection, display_ctrl = rtags_from_xsd_element('SEDABinaryDataObject', 'FileInfo')
@@ -667,7 +667,7 @@ class SEDANavigationTC(CubicWebTC):
             # unit2 is not related to a transfer, breadcrumbs leads to /sedalib.
             breadcrumbs = unit2.cw_adapt_to('IBreadCrumbs').breadcrumbs()
             expected_breadcrumbs = [
-                (u'http://testing.fr/cubicweb/sedalib', u'SEDAArchiveUnit_plural'),
+                (u'http://testing.cubicweb/cubicweb/sedalib', u'SEDAArchiveUnit_plural'),
                 unit2,
             ]
             self.assertEqual(breadcrumbs, expected_breadcrumbs)
